@@ -66,10 +66,10 @@ function (x, y, id, initial.values, control) {
     on.exit(options(old))
     # EM iterations
     iter <- control$iter.EM
-    Y.mat <- matrix(0, iter, ncx + 1)
-    T.mat <- matrix(0, iter, ncww + 1)
-    B.mat <- if (diag.D) matrix(0, iter, ncz) else matrix(0, iter, ncz * ncz)
-    lgLik <- numeric(iter)
+    Y.mat <- matrix(0, iter + 1, ncx + 1)
+    T.mat <- matrix(0, iter + 1, ncww + 1)
+    B.mat <- if (diag.D) matrix(0, iter + 1, ncz) else matrix(0, iter + 1, ncz * ncz)
+    lgLik <- numeric(iter + 1)
     conv <- FALSE
     for (it in 1:iter) {
         # save parameter values in matrix
@@ -179,7 +179,8 @@ function (x, y, id, initial.values, control) {
                 }
             }
         }
-                
+        if (iter == 0) break
+               
         # M-step
         if (it > 2) {
             Zb <- rowSums(Z * post.b[id, ], na.rm = TRUE)
@@ -228,8 +229,8 @@ function (x, y, id, initial.values, control) {
     colnames(post.b) <- colnames(x$Z)
     list(coefficients = list(betas = betas, sigma = sigma, gammas = gammas, alpha = alpha, 
         lambda0 = cbind("basehaz" = lambda0, "time" = unqT), D = as.matrix(D)), Hessian = Hessian, logLik = lgLik, 
-        EB = list(post.b = post.b, post.vb = post.vb, Zb = Zb, Ztimeb = rowSums(Ztime * post.b), 
-        Ztime2b = rowSums(Ztime2 * post.b[indT, ])), indexes = list(indT = indT, ind.L1 = ind.L1), 
+        EB = list(post.b = post.b, post.vb = post.vb, Zb = if (iter == 0) rowSums(Z * post.b[id, ], na.rm = TRUE) else Zb, 
+        Ztimeb = rowSums(Ztime * post.b), Ztime2b = rowSums(Ztime2 * post.b[indT, ])), indexes = list(indT = indT, ind.L1 = ind.L1), 
         iters = it, convergence = conv, n = n, N = N, ni = ni, d = d, id = id)
 }
 
